# Community Template Override Movable Type Plugin
# Copyright (C) 2008 Six Apart, Ltd.
# Licensed under the same terms as Perl itself

package MT::Plugin::CommunityTemplateOverride;

use strict;
use warnings;

use base qw( MT::Plugin );
use MT;

use vars qw( $VERSION $plugin );
$VERSION = '0.1';
$plugin = MT::Plugin::CommunityTemplateOverride->new ({
    id          => 'CommunityTemplateParameter',
    name        => 'Community Template Parameter',
    description => 'Adds support for a templ_id querystring parameter that when added to the URL will override the default template used to render and display results for the given mode, with the template identified by "tmpl_id."',
    version     => $VERSION,
    author_name => 'Six Apart',
    author_link => 'http://www.sixapart.com/',
});
MT->add_plugin ($plugin);

sub instance { $plugin }

sub init_registry {
    my $plugin = shift;
    my $reg = {
        init_app    => {
            'MT::App::Community'    => \&init_community_app,
        }
    };
    $plugin->registry ($reg);
}

sub init_community_app {
    local $SIG{__WARN__} = sub { };
    
    my $orig = \&MT::App::Community::load_global_tmpl;
    *MT::App::Community::load_global_tmpl = sub {
        my ($app) = @_;
        # Kick out if the tmpl_id parameter isn't used
        return $orig->(@_) unless ($app->param ('tmpl_id'));
        
        # Otherwise, load that puppy up and give it the defaults
        require MT::Template;
        my $tmpl = MT::Template->load( $app->param ('tmpl_id') );
        $app->set_default_tmpl_params($tmpl);
        $tmpl;
    }
}

1;
